pub struct DocBuffer { /* private fields */ }Expand description
A growable sink of Doc elements, the target of the doc_write! macro and of Format
implementors.
Implementations
Sourceimpl DocBuffer
impl DocBuffer
Sourcepub fn write_element(&mut self, doc: Doc)
pub fn write_element(&mut self, doc: Doc)
Append one already-built Doc element in order.
Sourcepub fn write_fmt_value<T: Format + ?Sized>(&mut self, value: &T)
pub fn write_fmt_value<T: Format + ?Sized>(&mut self, value: &T)
Append a value by letting it format itself into this buffer.
Sourcepub fn write_with_rule<T: ?Sized, R: FormatRule<T>>(
&mut self,
rule: &R,
item: &T,
)
pub fn write_with_rule<T: ?Sized, R: FormatRule<T>>( &mut self, rule: &R, item: &T, )
Append a value formatted by an external FormatRule.