pub fn format_with_diagnostics(
source: &str,
options: &FormatOptions,
) -> FormatResultExpand description
Format SQL and return parse diagnostics from the same lex/parse pass.
pub fn format_with_diagnostics(
source: &str,
options: &FormatOptions,
) -> FormatResultFormat SQL and return parse diagnostics from the same lex/parse pass.